#
# Copyright (c) 2001, 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Meta-Makefiles software.
# 
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#
###
### janos_rules.mk
###

include $(CONFIG_FILE)
include $(MAKEFILES_DIR)/std_vars.mk
include $(MAKEFILES_DIR)/oskit_vars.mk
include $(MAKEFILES_DIR)/moab_vars.mk
include $(MAKEFILES_DIR)/janosvm_vars.mk
include $(MAKEFILES_DIR)/jnodeos_vars.mk
include $(MAKEFILES_DIR)/antsr_vars.mk
include $(MAKEFILES_DIR)/janos_vars.mk

.PHONY: scripts configs config all depend

config depend all:
	@echo "ERROR: 'janos' is not a component that support $@"
	@false

check: $(janos_SCRIPTS)
ifeq ($(std_moab_included),yes)
	$(MAKE) -C $(moab_OBJ_DIR) check
endif
ifeq ($(std_janos_included),yes)
	$(MAKE) -C $(janos_OBJ_DIR)/tests check
endif
ifeq ($(std_jnodeos_included),yes)
	JAVA=$(janos_INSTALL_DIR)/bin/jnodeos \
		JANOS_NODEOS=$(jnodeos_BACKEND) \
		$(jnodeos_OBJ_DIR)/check
endif
ifeq ($(std_antsr_included),yes)
	JAVA=$(janos_INSTALL_DIR)/bin/antsr \
		JANOS_NODEOS=$(jnodeos_BACKEND) \
		$(MAKE) -C $(antsr_OBJ_DIR) check
endif

install: scripts configs

scripts: $(janos_SCRIPTS)
	@test -z "$^" || chmod +x $^

configs: $(janos_CONFIGS)

$(janos_INSTALL_DIR): 
	@test -d $@ || mkdir $@

$(janos_INSTALL_DIR)/bin: $(janos_INSTALL_DIR) 
	@test -d $@ || mkdir $@

$(janos_INSTALL_DIR)/etc: $(janos_INSTALL_DIR) 
	@test -d $@ || mkdir $@

## Scripts
_nodeosMain=edu.utah.janos.nodeos.Main

$(janos_ANTSR): $(janos_INSTALL_DIR)/bin FORCE
	@rm -f $@
	@echo "#!/bin/sh">$@
	@echo 'CLASSPATH="$(janosvm_JANOSVM_JAR):$(jnodeos_CLASSES_JAR):$(jnodeos_CLASSESTESTS_JAR):$(antsr_CLASSES_JAR):$(antsr_CLASSESAPPS_JAR):$(antsr_CLASSESTESTS_JAR)$${CLASSPATH:+:$${CLASSPATH}}"'>>$@
	@echo "export CLASSPATH">>$@
	@echo " ">>$@
	@echo 'exec $(janosvm_INSTALL_DIR)/bin/janosvm -config $(janos_ETC_ANTSR) "$$@"'>>$@
	@echo "#eof">>$@
	@echo "Created script $@"

$(janos_JNODEOS): $(janos_INSTALL_DIR)/bin FORCE
	@rm -f $@
	@echo "#!/bin/sh">$@
	@echo 'CLASSPATH="$(janosvm_JANOSVM_JAR):$(jnodeos_CLASSES_JAR):$(jnodeos_CLASSESTESTS_JAR)$${CLASSPATH:+:$${CLASSPATH}}"'>>$@
	@echo "export CLASSPATH">>$@
	@echo " ">>$@
	@echo 'exec $(janosvm_INSTALL_DIR)/bin/janosvm -config $(janos_ETC_JNODEOS) "$$@"'>>$@
	@echo "#eof">>$@
	@echo "Created script $@"

$(janos_JANOSVM): $(janos_INSTALL_DIR)/bin FORCE
	@rm -f $@
	@echo "#!/bin/sh">$@
	@echo 'CLASSPATH="$(janosvm_JANOSVM_JAR)$${CLASSPATH:+:$${CLASSPATH}}"'>>$@
	@echo "export CLASSPATH">>$@
	@echo " ">>$@
	@echo 'exec $(janosvm_INSTALL_DIR)/bin/janosvm -config $(janos_ETC_JANOSVM) "$$@"'>>$@
	@echo "#eof">>$@
	@echo "Created script $@"

## Config files
$(janos_ETC_ANTSR): $(janos_INSTALL_DIR)/etc $(janos_ETC_JNODEOS) FORCE
	@rm -f $@
	@echo "# ANTSR extends jnodeos system classes">$@
	@echo "%include \"$(janos_ETC_JNODEOS)\"">>$@
	@echo "# ANTSR system classes">>$@
	@echo "%begin namespace-resource">>$@
	@echo " %begin classgroup antsr">>$@
# XXX this should be better (includes ants.apps right now...)?
	@(cd $(antsr_OBJ_DIR)/src; find ants -name '*.class' | sed -e 's/\.class//' -e 's/^/  /')>>$@
	@echo " %end">>$@
	@echo "%end">>$@
	@echo "Created config $@"

$(janos_ETC_JNODEOS): $(janos_INSTALL_DIR)/etc $(janos_ETC_JANOSVM) FORCE
	@rm -f $@
	@echo "# jnodeos extends JanosVM system classes">$@
	@echo "%include \"$(janos_ETC_JANOSVM)\"">>$@
# Tell moab what namespaces it should export 
	@echo "%begin pairs JanosConfig">>$@
	@echo "  exported-namespace jnodeos">>$@
	@echo "%end">>$@
# Cause the config init to load the moab glue library
	@echo "%begin libraries">>$@
	@echo "  # kaffenodeos # Moab glue library">>$@
	@echo "%end">>$@
	@echo "# jnodeos system classes">>$@
	@echo "%begin namespace-resource">>$@
	@echo " %begin classgroup jnodeos">>$@
	@(cd $(jnodeos_OBJ_DIR)/classes-$(jnodeos_BACKEND)-$(WAY); find edu/utah/janos/nodeos -name '*.class' | sed -e 's/\.class//' -e 's/^/  /')>>$@
	@(cd $(jnodeos_OBJ_DIR)/classes-$(jnodeos_BACKEND)-$(WAY); find edu/utah/janos/util -name '*.class' | sed -e 's/\.class//' -e 's/^/  /')>>$@
	@(cd $(jnodeos_OBJ_DIR)/classes-$(jnodeos_BACKEND)-$(WAY); find edu/utah/janos/io -name '*.class' | sed -e 's/\.class//' -e 's/^/  /')>>$@
	@(cd $(jnodeos_OBJ_DIR)/classes-$(jnodeos_BACKEND)-$(WAY); find edu/utah/janos/protocols -name '*.class' | sed -e 's/\.class//' -e 's/^/  /')>>$@
	@(cd $(jnodeos_OBJ_DIR)/classes-$(jnodeos_BACKEND)-$(WAY); find edu/utah/janos/route -name '*.class' | sed -e 's/\.class//' -e 's/^/  /')>>$@
	@echo " %end">>$@
	@echo "%end">>$@
	@echo "Created config $@"

$(janos_ETC_JANOSVM): $(janos_INSTALL_DIR)/etc FORCE
	@rm -f $@
	@echo "# janosvm extends raw system classes">$@
	@echo "%include \"$(janosvm_INSTALL_DIR)/etc/janosvm-root.config\"">>$@
	@echo "%include \"$(janosvm_INSTALL_DIR)/etc/janosvm-fake.config\"">>$@
	@echo "# janosvm kernel system classes">>$@
# Define the kernel API for the JanosVM
	@echo "%begin namespace-resource">>$@
	@echo " %begin classgroup kernel">>$@
	@unzip -v $(janosvm_JANOSVM_JAR) | grep "edu" | sed -e 's/^.*edu/edu/' -e 's/.class//' -e 's/^/  /'>>$@
	@unzip -v $(janosvm_JANOSVMKIT_JAR) | grep "edu" | sed -e 's/^.*edu/edu/' -e 's/.class//' -e 's/^/  /'>>$@
	@echo " %end">>$@
	@echo "%end">>$@
	@echo "Created config $@"

# XXX only good for building JanosVM-based bmods.  (E.g., not for simpler Moab-based EEs).
bmod: configs $(janos_ARCHVIES_SANITY)
	@if test -z "$(janos_BMOD_DIR)"; then \
		echo "Must set the janos_BMOD_DIR variable"; \
		exit 11; \
	fi
	@test -d $(janos_BMOD_DIR) || mkdir -p $(janos_BMOD_DIR)
	@for archive in \
		$(janos_JANOSVM_CLASS_ARCHIVES) \
		$(janos_JNODEOS_CLASS_ARCHIVES) \
		$(janos_ANTSR_CLASS_ARCHIVES) \
		; do \
		test -f "$$archive" || (echo "ERROR: Required archive $$archive not available."; exit 11) \
	done
	@$(janosvm_SRC_DIR)/config/i386/nodeos/mkimage.sh \
		--kerneldir=$(janos_BMOD_DIR) \
		--kaffedir=$(janosvm_INSTALL_DIR) \
		--oskitdir=$(oskit_INSTALL_DIR) \
		--skipdefaultclasses \
		$(addprefix --classarchive=, $(janos_JANOSVM_CLASS_ARCHIVES)) \
		$(addprefix --classarchive=, $(janos_JNODEOS_CLASS_ARCHIVES)) \
		$(janos_CONFIG_MAPS) \
		$(addprefix --explicitfile=, $(janos_BMOD_EXTRAFILES))


FORCE:

mkdebug:
	@echo "janos_ANTSR   = $(janos_ANTSR)"
	@echo "janos_JNODEOS = $(janos_JNODEOS)"
	@echo "janos_SCRIPTS = $(janos_SCRIPTS)"
	@echo "janos_CONFIGS = $(janos_CONFIGS)"
	@echo "janos_CONFIG_MAPS = $(janos_CONFIG_MAPS)"
	@echo "janos_BMOD_DIR= $(janos_BMOD_DIR)"
	@echo "janos_CLASS_ARCHVIES= $(janos_CLASS_ARCHIVES)"

#eof
