#
# Copyright (c) 2001, 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Meta-Makefiles software.
# 
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#
###
### janos_vars.mk
###

include $(CONFIG_FILE)
include $(MAKEFILES_DIR)/std_vars.mk
include $(MAKEFILES_DIR)/janosvm_vars.mk

janos_INSTALL_DIR=$(INSTALL_DIR)/janos-$(janosvm_HOST)
janos_BMOD_DIR:=$(INSTALL_DIR)

## Scripts for running different variations on Java Janos
janos_ANTSR=$(janos_INSTALL_DIR)/bin/antsr
janos_JNODEOS=$(janos_INSTALL_DIR)/bin/jnodeos
janos_JANOSVM=$(janos_INSTALL_DIR)/bin/janosvm

## Config files
janos_ETC_ANTSR=$(janos_INSTALL_DIR)/etc/jvm-antsr.config
janos_ETC_JNODEOS=$(janos_INSTALL_DIR)/etc/jvm-jnodeos.config
janos_ETC_JANOSVM=$(janos_INSTALL_DIR)/etc/jvm-janosvm.config
janos_ETC_JANOSVM_ROOT=$(janosvm_INSTALL_DIR)/etc/janosvm-root.config
janos_ETC_JANOSVM_FAKE=$(janosvm_INSTALL_DIR)/etc/janosvm-fake.config

# Just use the automagically generated classpath file
# janos_ETC_KAFFE_CLASSPATH=$(janos_INSTALL_DIR)/etc/kaffe_classpath

###
### Build the list of actual config files and scripts to be installed
### based on which components have been 
###

# The JanosVM configuration files to install
janos_CONFIGS:=
# The variations on Janos startup scripts to install
janos_SCRIPTS:=
# The mapping of etc config files into an OSKit BMOD
janos_CONFIG_MAPS:=
# The list of rules for doing sanity checks on the archives
janos_ARCHVIES_SANITY:=

ifeq ($(std_antsr_included),yes)
janos_CONFIGS+= $(janos_ETC_ANTSR)
janos_CONFIG_MAPS+=--explicitfile=$(janos_ETC_ANTSR):/etc/janosvm/antsr.config --explicitfile=$(janos_ETC_ANTSR)
janos_SCRIPTS+= $(janos_ANTSR)
janos_ANTSR_CLASS_ARCHIVES=$(antsr_CLASSES_JAR) $(antsr_CLASSESAPPS_JAR) $(antsr_CLASSESTESTS_JAR)
janos_ARCHIVES_SANITY+=antsr_archives_sanity
antsr_archives_sanity:
	test -n "$(antsr_CLASSES_JAR)" || (echo "ERROR: antsr_CLASSES_JAR is empty"; exit 1)
	test -n "$(antsr_CLASSESAPPS_JAR)" || (echo "ERROR: antsr_CLASSESAPPS_JAR is empty"; exit 1)
	test -n "$(antsr_CLASSESTESTS_JAR)" || (echo "ERROR: antsr_CLASSESTESTS_JAR is empty"; exit 1)

endif

ifeq ($(std_jnodeos_included),yes)
janos_CONFIGS+= $(janos_ETC_JNODEOS)
janos_CONFIG_MAPS+=--explicitfile=$(janos_ETC_JNODEOS):/etc/janosvm/jnodeos.config --explicitfile=$(janos_ETC_JNODEOS)
janos_SCRIPTS+= $(janos_JNODEOS)
janos_JNODEOS_CLASS_ARCHIVES= $(jnodeos_CLASSES_JAR) $(jnodeos_CLASSESTESTS_JAR)
janos_ARCHIVES_SANITY+=jnodeos_archives_sanity
jnodes_archives_sanity:
	test -n "$(jnodeos_CLASSES_JAR)" || (echo "ERROR: jnodeos_CLASSES_JAR is empty"; exit 1)
	test -n "$(jnodeos_CLASSESTESTS_JAR)" || (echo "ERROR: jnodeos_CLASSESTESTS_JAR is empty"; exit 1)
endif

ifeq ($(std_janosvm_included),yes)
janos_CONFIGS+= $(janos_ETC_JANOSVM)
janos_CONFIG_MAPS+=\
	--explicitfile=$(janos_ETC_JANOSVM) \
	--explicitfile=$(janos_ETC_JANOSVM):/etc/janosvm/base.config

#	--explicitfile=$(janosvm_INSTALL_DIR)/etc/janosvm-root.config:$(janosvm_SRC_DIR)/kaffe/etc/janosvm-root.config
#	--explicitfile=$(janosvm_SRC_DIR)/test/janosvm/jvm.config.in

janos_CONFIG_MAPS+=\
	--explicitfile=$(janos_ETC_JANOSVM_ROOT) \
	--explicitfile=$(janos_ETC_JANOSVM_ROOT):/etc/janosvm/root.config \
	--explicitfile=$(janos_ETC_JANOSVM_FAKE) \
	--explicitfile=$(janos_ETC_JANOSVM_FAKE):/etc/janosvm/fake.config \
	--explicitfile=$(janosvm_SRC_DIR)/kaffe/etc/janosvm-root.config \
	--explicitfile=$(janosvm_SRC_DIR)/test/janosvm/jvm.config.in \
	--explicitfile=$(janosvm_OBJ_DIR)/test/janosvm/jvm.config:/etc/janosvm/tests.config

janos_SCRIPTS+= $(janos_JANOSVM)
janos_JANOSVM_CLASS_ARCHIVES= $(janosvm_JANOSVM_JAR) $(janosvm_JANOSVMKIT_JAR)
janos_ARCHIVES_SANITY+=janosvm_archives_sanity
janosvm_archives_sanity:
	test -n "$(janosvm_JANOSVM_JAR)" || (echo "ERROR: janosvm_JANOSVM_JAR is empty"; exit 1)
	test -n "$(janosvm_JANOSVMKIT_JAR)" || (echo "ERROR: janosvm_JANOSVMKIT_JAR is empty"; exit 1)
endif

#eof
