#
# Copyright (c) 2001, 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Meta-Makefiles software.
# 
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#
##
## Pat's local Makefile for compiling JanosVM
##

include $(CONFIG_FILE)
include $(MAKEFILES_DIR)/std_vars.mk
## JanosVM touches just about everything else...
include $(MAKEFILES_DIR)/moab_vars.mk 
include $(MAKEFILES_DIR)/jnodeos_vars.mk 
include $(MAKEFILES_DIR)/janosvm_vars.mk 
include $(MAKEFILES_DIR)/oskit_vars.mk 
include $(MAKEFILES_DIR)/click_vars.mk 
include $(MAKEFILES_DIR)/antsr_vars.mk

.PHONY: bmod rmkaffe check devconf vmlib
.PHONY: classes klasses Klasses relink

# XXX move to top-level GNUmakefile options...
AUTOMAKE=automake ## v1.4
#AUTOMAKE=/n/alta/z/tullmann/janos/install/tools/bin/automake-cobbs ## v1.4a-dep++
#AUTOMAKE=/n/alta/z/tullmann/janos/install/tools/bin/automake ## CVS

devconf: hostcheck
	cd $(janosvm_SRC_DIR) && aclocal -I .
	cd $(janosvm_SRC_DIR) && autoheader -l config
	cd $(janosvm_SRC_DIR) && $(AUTOMAKE)  --add-missing --verbose || true
	cd $(janosvm_SRC_DIR) && autoconf

$(janosvm_SRC_DIR)/configure: $(janosvm_SRC_DIR)/configure.in
	@echo "*** JanosVM configure is out of date, you must rebuild it ***"
	@echo "You should use the janosvm-devconf target to accomplish that."
	@ls -la $(janosvm_SRC_DIR)/configure.in
	@ls -la $(janosvm_SRC_DIR)/configure
	@false

$(janovm_CLASSSES_JAR): 
	@echo "XXX assuming $(janovm_CLASSSES_JAR) is up to date."

check: hostcheck
	-(cd $(janosvm_OBJ_DIR)/test/regression && $(MAKE) check)
	-(cd $(janosvm_OBJ_DIR)/test/janosvm && $(MAKE) check $(janosvm_CHECK_HACKS))

vmcheck: hostcheck
	-(cd $(janosvm_OBJ_DIR)/test/janosvm && $(MAKE) check $(janosvm_CHECK_HACKS))

rmkaffe: hostcheck
	rm -f $(janosvm_OBJ_DIR)/kaffe/kaffe/Kaffe

relink: hostcheck rmkaffe
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) \
		-C $(janosvm_OBJ_DIR)/kaffe/kaffe install

jvmlib: hostcheck
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) \
		-C $(janosvm_OBJ_DIR)/libraries/jvmlib compile-classes

vmlib: hostcheck
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) \
		-C $(janosvm_OBJ_DIR)/kaffe/kaffevm install

anlib: hostcheck
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) \
		-C $(janosvm_OBJ_DIR)/libraries/extensions/nodeos/clib install

classes: klasses janosvmjar emulibjar kitlibjar
# XXX following four rules do not parallelize correctly.
klasses Klasses: _build-Klasses _install-Klasses
janosvmjar janosvm.jar JanosVM.jar: _build-JanosVMJar _install-JanosVMJar
emulib emulibjar emujanosvm.jar emuJanosVM.jar: _build-emuJanosVMJar _install-emuJanosVMJar
kitlib kitlibjar janosvmkit.jar JanosVMKit.jar: _build-JanosVMKitJar _install-JanosVMKitJar

###
### Internal rules
###

.PHONY: _build-Klasses _install-Klasses
.PHONY: _build-JanosVMJar _install-JanosVMJar
.PHONY: _build-emuJanosVMJar _install-emuJanosVMJar
.PHONY: _build-kitJanosVMJar _install-kitJanosVMJar

_build-Klasses: hostcheck
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) \
		-C $(janosvm_OBJ_DIR)/ Klasses

_install-Klasses: hostcheck
	test -d "$(janosvm_INSTALL_DIR)/share/kaffe/" || \
		mkdir -p "$(janosvm_INSTALL_DIR)/share/kaffe/"
	cp $(janosvm_OBJ_DIR)/libraries/javalib/lib/Klasses.jar $(janosvm_INSTALL_DIR)/share/kaffe/Klasses.jar

_build-JanosVMJar: hostcheck
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) \
		-C $(janosvm_OBJ_DIR)/ JanosVM

_install-JanosVMJar: hostcheck
	test -d "$(janosvm_INSTALL_DIR)/share/kaffe/" || \
		mkdir -p "$(janosvm_INSTALL_DIR)/share/kaffe/"
	cp $(janosvm_OBJ_DIR)/libraries/jvmlib/lib/JanosVM.jar $(janosvm_INSTALL_DIR)/share/kaffe/JanosVM.jar

_build-emuJanosVMJar: hostcheck
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) \
		-C $(janosvm_OBJ_DIR)/ emuJanosVM

_install-emuJanosVMJar: hostcheck
	test -d "$(janosvm_INSTALL_DIR)/share/kaffe/" || \
		mkdir -p "$(janosvm_INSTALL_DIR)/share/kaffe/"
	cp $(janosvm_OBJ_DIR)/libraries/emulib/lib/emuJanosVM.jar $(janosvm_INSTALL_DIR)/share/kaffe/emuJanosVM.jar

_build-JanosVMKitJar: hostcheck
	$(janosvm_BUILDENV) $(MAKE) $(std_MAKE_QUIET) \
		-C $(janosvm_OBJ_DIR)/ JanosVMKit

_install-JanosVMKitJar: hostcheck
	test -d "$(janosvm_INSTALL_DIR)/share/kaffe/" || \
		mkdir -p "$(janosvm_INSTALL_DIR)/share/kaffe/"
	cp $(janosvm_OBJ_DIR)/libraries/kitlib/lib/JanosVMKit.jar $(janosvm_INSTALL_DIR)/share/kaffe/JanosVMKit.jar


###
### XXX bmod and symtrace commands are bogus
###

bmod:
	@rm -f $(janosvm_OBJ_DIR)/Image
	$(janosvm_SRC_DIR)/config/i386/oskit/mkimage.sh \
		--kaffedir=$(janosvm_INSTALL_DIR) \
		--kerneldir=$(janosvm_INSTALL_DIR) \
		--oskitdir=$(oskit_INSTALL_DIR) \
		--makeimage=mkmb2
	cp $(janosvm_INSTALL_DIR)/Image kerneldir/kernelname

## bmod.<machine>-<fs>, as in bmod.diecy-hw or bmod.wren-janos
bmod.%:
	@rm -f $(janosvm_OBJ_DIR)/Image
	@janosvm_SRC_DIR=$(janosvm_SRC_DIR) \
		janosvm_INSTALL_DIR=$(janosvm_INSTALL_DIR) \
		OSKITDIR=$(oskit_INSTALL_DIR) \
		KERNEL=KERNELDIR/KERNELNAME \
		GDBARG=$(GDBARG) \
		sh $(janosvm_SRC_DIR)/mkimagepat.sh $(*)

bmodcmd.%:
	@rm -f $(janosvm_OBJ_DIR)/Image
	@janosvm_SRC_DIR=$(janosvm_SRC_DIR) \
		janosvm_INSTALL_DIR=$(janosvm_INSTALL_DIR) \
		OSKITDIR=$(oskit_INSTALL_DIR) \
		KERNEL=KERNELDIR/KERNELNAME \
		GDBARG=$(GDBARG) \
		sh $(janosvm_SRC_DIR)/mkimagepat.sh $(*) justcmd

symtrace:
	@echo ">>> Paste backtraces to stdin <<<"
	@$(janosvm_SRC_DIR)/developers/btparse.pl \
		$(oskit_INSTALL_DIR)/bin/sym-trace \
		$(janosvm_INSTALL_DIR)/libexec/Kaffe

mkdebug::
	@echo "janosvm_LOCAL_JSIHEY  = $(janosvm_LOCAL_JSIHEY)"
	@echo "janosvm_LOCAL_KAFFEH  = $(janosvm_LOCAL_KAFFEH)"
	@echo "janosvm_CLASSES_JAR   = $(janosvm_CLASSES_JAR)"
	@echo "janosvm_JANOSVM_JAR   = $(janosvm_JANOSVM_JAR)"
	@echo "janosvm_EMUJANOSVM_JAR= $(janosvm_EMUJANOSVM_JAR)"
	@echo "janosvm_JANOSVM       = $(janosvm_JANOSVM)"

component=janosvm
include $(MAKEFILES_DIR)/std_rules.mk
