#
# Copyright (c) 2001, 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Meta-Makefiles software.
# 
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#
###
### janosvm_vars.mk
###

include $(CONFIG_FILE)
include $(MAKEFILES_DIR)/std_vars.mk
include $(MAKEFILES_DIR)/janosvmtools_vars.mk

ifeq ($(std_janosvmtools_included),yes)
janosvm_LOCAL_KAFFEH=$(janosvmtools_INSTALL_DIR)/bin/kaffeh
janosvm_LOCAL_JSIHEY=$(janosvmtools_INSTALL_DIR)/bin/jsihey
endif

ifeq ($(std_moab_included),yes)
janosvm_HOST=moab$(moab_HOST)
else
janosvm_HOST=unix
endif

### JanosVM config based on WAY
ifeq ($(WAY),debug)
janosvm_CONFIGDEBUG=--enable-debug --enable-xdebugging
janosvm_CONFIGENV=
else
ifeq ($(WAY),optimized)
## XXX Force static libraries?
janosvm_LIBS=static
janosvm_CONFIGDEBUG=--disable-debug --without-x
janosvm_CONFIGENV=CFLAGS='-O2'
else
ifeq ($(WAY),profile)
## XXX Force static libraries?
janosvm_LIBS=static
janosvm_CONFIGSTAT=--with-stats --enable-xprofiling --with-profiling --without-x
janosvm_CONFIGENV=CFLAGS='-O2'
endif
endif
endif

ifeq ($(janosvm_ENGINE),jit)
janosvm_CONFIGENGINE=--with-engine=jit3
else
janosvm_CONFIGENGINE=--with-engine=$(janosvm_ENGINE)
endif

ifeq ($(janosvm_LIBS),static)
janosvm_CONFIGLIBSTYLE=--with-staticvm --with-staticlib
else
janosvm_CONFIGLIBSTYLE=
endif

## Hacks for doing a make check in janosvm/test/janosvm.
ifeq ($(std_moab_included),yes)
janosvm_CHECK_HACKS=JSICLIENT=$(janosvm_LOCAL_JSIHEY) TEST_FILE=TestCommHack
else
janosvm_CHECK_HACKS=
endif

###
### Configure info for different hosts of Kaffe
###

janosvm_CONFIGMOABCOMMON=--srcdir=$(janosvm_SRC_DIR) \
	--oskitdir=$(oskit_INSTALL_DIR) \
	--localkaffeh=$(janosvm_LOCAL_KAFFEH) \
	--disable-gcj


ifeq ($(janosvm_HOST),unix)
janosvm_CONFIGSCRIPT=$(janosvm_SRC_DIR)/configure
janosvm_CONFIGPLAT=
janosvm_CONFIGCLICK=

else
janosvm_BUILDENV=JNODEOS_CLASSES_ZIP=$(jnodeos_CLASSES_JAR) JANOSVM_CLASSES_ZIP=$(janosvm_JANOSVM_JAR)
ifeq ($(janosvm_HOST),moaboskit)
janosvm_CONFIGSCRIPT=$(janosvm_SRC_DIR)/config/i386/nodeos/nodeos-configure
janosvm_CONFIGPLAT=$(janosvm_CONFIGMOABCOMMON) \
		--nodeosdir=$(moab_INSTALL_DIR)

ifeq ($(std_click_included),yes)
janosvm_CONFIGCLICK=--clickdir=$(click_INSTALL_DIR)
endif
else
ifeq ($(janosvm_HOST),moaboskitunix)
janosvm_CONFIGSCRIPT=$(janosvm_SRC_DIR)/config/i386/nodeos/nodeos-configure
janosvm_CONFIGPLAT=$(janosvm_CONFIGMOABCOMMON) \
		--nodeosdir=$(moab_INSTALL_DIR) \
		--nodeosunix
ifeq ($(std_click_included),yes)
janosvm_CONFIGCLICK=--clickdir=$(click_INSTALL_DIR)
endif
else
ifeq ($(janosvm_HOST),moabunix)
janosvm_CONFIGSCRIPT=$(janosvm_SRC_DIR)/config/i386/nodeos/nodeos-configure
janosvm_CONFIGPLAT=--nodeosdir=$(moab_INSTALL_DIR) \
		--nodeosunix
janosvm_CONFIGCLICK=

endif
endif
endif
endif

janosvm_OBJ_DIR=$(OBJ_DIR)/janosvm-${janosvm_ENGINE}-${WAY}-$(janosvm_HOST)-${janosvm_LIBS}
janosvm_INSTALL_DIR=$(INSTALL_DIR)/janosvm-${janosvm_ENGINE}-${WAY}-$(janosvm_HOST)-${janosvm_LIBS}

janosvm_CONFIGOPTS=--prefix=$(janosvm_INSTALL_DIR) \
		--disable-gcj \
		${janosvm_CONFIGENGINE} \
		${janosvm_CONFIGDEBUG} \
		${janosvm_CONFIGLIBSTYLE} \
		${janosvm_CONFIGPLAT} \
		${janosvm_CONFIGCLICK}

ifeq ($(std_janosvm_included),yes)
janosvm_CLASSES_JAR=$(janosvm_SRC_DIR)/libraries/javalib/Klasses.jar
janosvm_JANOSVM_JAR=$(janosvm_SRC_DIR)/libraries/jvmlib/JanosVM.jar
janosvm_JANOSVMKIT_JAR=$(janosvm_SRC_DIR)/libraries/kitlib/JanosVMKit.jar
janosvm_EMUJANOSVM_JAR=$(janosvm_SRC_DIR)/libraries/jvmlib/emuJanosVM.jar
janosvm_JANOSVM=$(janosvm_INSTALL_DIR)/bin/kaffe
else
janosvm_CLASSES_JAR=$(JVM_CORE_CLASSES)
janosvm_JANOSVM_JAR=$(janosvm_SRC_DIR)/libraries/jvmlib/JanosVM.jar
janosvm_JANOSVMKIT_JAR=$(janosvm_SRC_DIR)/libraries/kitlib/JanosVMKit.jar
janosvm_EMUJANOSVM_JAR=$(janosvm_SRC_DIR)/libraries/jvmlib/emuJanosVM.jar
janosvm_JANOSVM=java
endif


#eof
