#
# Copyright (c) 2001 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Meta-Makefiles software.
# 
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#
##
## A convenience makefile for constructing/configuring Moab.
##

include $(CONFIG_FILE)
include $(MAKEFILES_DIR)/std_vars.mk
include $(MAKEFILES_DIR)/click_vars.mk
include $(MAKEFILES_DIR)/oskit_vars.mk
include $(MAKEFILES_DIR)/moab_vars.mk

$(moab_CONFIGSCRIPT): $(moab_SRC_DIR)/configure.in
	@echo "*** Moab's configure is out of date, you must rebuild it ***"
	@ls -la configure.in
	@ls -la configure
	@false

prof all_p: hostcheck
	  @if test $(BUILD) = "profile"; then \
		  $(MAKE) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) -C $(OBJDIR) all_p; \
	  else \
		  echo "IMPLYING BUILD=profile"; \
		  $(MAKE) -f NodeOSMakefile BUILD=profile all_p; \
	  fi

opt all_o: hostcheck
	@if test $(BUILD) = "optimized"; then \
		$(MAKE) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) -C $(OBJDIR) all_o; \
	else \
		echo "IMPLYING BUILD=optimized"; \
		$(MAKE) -f NodeOSMakefile BUILD=optimized all_o; \
	fi

envs:
	$($(component)_BUILDENV) \
		$($(component)_BUILDTOOL) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) \
		-C $($(component)_OBJ_DIR)/envs \
		all

fdoom:
	$($(component)_BUILDENV) \
		$($(component)_BUILDTOOL) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) \
		-C $($(component)_OBJ_DIR)/envs/fdoom \
		all

adoom:
	$($(component)_BUILDENV) \
		$($(component)_BUILDTOOL) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) \
		-C $($(component)_OBJ_DIR)/envs/adoom \
		all

bmod: 
	@if test -z "$(BMOD_EE)"; then echo "Must define BMOD_EE as env to put in bmod"; exit 1; fi
	@if test ! -f "$(moab_OBJ_DIR)/envs/$(BMOD_EE)"; then echo "BMOD_EE=$(BMOD_EE) is not a Moab EE."; exit 1; fi
	@mkmb2 -o $(moab_INSTALL_DIR)/Image $(moab_OBJ_DIR)/envs/$(BMOD_EE)
	@echo "Created $(moab_INSTALL_DIR)/Image"

symtrace:
	@if test -z "$(BMOD_EE)"; then echo "Must define BMOD_EE to backtrace in"; exit 1; fi
	@if test ! -f "$(moab_OBJ_DIR)/envs/$(BMOD_EE)"; then echo "BMOD_EE=$(BMOD_EE) is not a Moab EE."; exit 1; fi
	@echo ">>> Paste backtraces to stdin <<<"
	@$(janosvm_SRC_DIR)/developers/btparse.pl \
		$(oskit_INSTALL_DIR)/bin/sym-trace \
		$(moab_OBJ_DIR)/envs/$(BMOD_EE)

check:
	$(MAKE) -C $(moab_OBJ_DIR)/envs check

component=moab
include $(MAKEFILES_DIR)/std_rules.mk

#eof
