#
# Copyright (c) 2001, 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Meta-Makefiles software.
# 
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#
###
### std_rules.mk
###
### Convenience makefile included by the different component makefiles.
###

include $(CONFIG_FILE)
include $(MAKEFILES_DIR)/std_vars.mk

# Use '$(MAKE) as the default build tool
ifeq ($($(component)_BUILDTOOL),)
$(component)_BUILDTOOL=$(MAKE)
endif

# Use '$(MAKE) install' as the default INSTALLTOOL
ifeq ($($(component)_INSTALLTOOL),)
$(component)_INSTALLTOOL=$($(component)_BUILDTOOL) \
	$(std_MAKE_PARALLEL) $(std_MAKE_QUIET) \
	-C $($(component)_OBJ_DIR) \
	install
endif

# Use 4 as the default parallelism 
ifeq ($($(component)_MAKE_PARALLELISM),)
$(component)_MAKE_PARALLELISM=4
endif

ifeq ($($(component)_CONFIGSCRIPT),)
$(component)_CONFIGSCRIPT=$($(component)_SRC_DIR)/configure
endif

.PHONY: default hostcheck reconf config patch unpatch
.PHONY: depend all install clean 
.PHONY: clearconfig cleanconfig configclean
.PHONY: misc debug realclean

default: hostcheck
	@echo "pick a target (depend, all, install, clean, realclean, config, debug), fool."
	@false

clearconfig cleanconfig configclean:
	rm -f $($(component)_OBJ_DIR)/config.cache
	rm -rf $($(component)_OBJ_DIR)/conftest

reconf: hostcheck
	cd $($(component)_OBJ_DIR) && config.status

$($(component)_OBJ_DIR):
	@if mkdir "$@"; test $$? -ne 0; then \
		echo "ERROR: $(component)'s object directory could not be created."; \
		echo "	Tried: mkdir $@"; \
		exit 1; \
	fi

config: hostcheck $($(component)_CONFIGSCRIPT) $($(component)_OBJ_DIR) 
	chmod u+rx $($(component)_CONFIGSCRIPT)
	cd $($(component)_OBJ_DIR) && $($(component)_CONFIGENV) \
		$($(component)_CONFIGSCRIPT) \
		$($(component)_CONFIGOPTS)

patch: hostcheck
ifneq ($(PATCH_FILE),)
	patch --directory=$($(component)_SRC_DIR) --batch < $(CURDIR)/patches/$(PATCH_FILE)
	mv $(CURDIR)/patches/$(PATCH_FILE) $(CURDIR)/patches-applied
else
ifneq ($(wildcard $(CURDIR)/patches/$(component)*.patch),)
	$(foreach patch,$(sort $(wildcard $(CURDIR)/patches/$(component)*.patch)),patch --directory=$($(component)_SRC_DIR) --batch < $(patch) && mv $(patch) $(CURDIR)/patches-applied;)
#	mv $(CURDIR)/patches/$(component)*.patch $(CURDIR)/patches-applied
#	-@rm $(CURDIR)/patches/*~ # Trash emacs backup files
else
	@echo Could not find any patches in $(CURDIR)/patches to apply for $(component).  \(Patches must be of the form $(component)-\<desc\>.patch, e.g. oskit-console.patch\)
endif
endif

unpatch: hostcheck
ifneq ($(PATCH_FILE),)
	patch --directory=$($(component)_SRC_DIR) --batch --reverse < $(CURDIR)/patches-applied/$(PATCH_FILE)
	mv $(CURDIR)/patches-applied/$(PATCH_FILE) $(CURDIR)/patches
else
ifneq ($(wildcard $(CURDIR)/patches-applied/$(component)*.patch),)
	echo $(wildcard $(CURDIR)/patches-applied/$(component)*.patch) | sort -r | xargs cat | patch --directory=$($(component)_SRC_DIR) --batch --reverse
	mv $(CURDIR)/patches-applied/$(component)*.patch $(CURDIR)/patches
#	-@rm $(CURDIR)/patches/*~ # Trash emacs backup files
else
	@echo Could not find any patches in $(CURDIR)/patches-applied to remove from $(component)
endif
endif

## Non-parallel builds
distclean: hostcheck
	$($(component)_BUILDENV) \
		$($(component)_BUILDTOOL) $(std_MAKE_QUIET) \
		-C $($(component)_OBJ_DIR) \
		$@

## Parallel builds
depend all clean: hostcheck
	$($(component)_BUILDENV) \
		$($(component)_BUILDTOOL) $(std_MAKE_QUIET) $(std_MAKE_PARALLEL) \
		-C $($(component)_OBJ_DIR) \
		$@

## Install rules
install: hostcheck
	$($(component)_BUILDENV) \
		$($(component)_INSTALLTOOL)

realclean:
	rm -rf $($(component)_OBJ_DIR)
	rm -rf $($(component)_INSTALL_DIR)
	mkdir $($(component)_OBJ_DIR)
	mkdir $($(component)_INSTALL_DIR)

## Hehe.  Generate "help" by grepping through this file and the component-specific
## rules file and pulling out all the targets that don't start with an underscore.
## The 'sed' trims off the : and the dependencies, and adds the component name
## as a prefix.
help:
	@echo "The following public targets are available (via grep/sed magic): "
	@grep -h "^[a-zA-Z][a-zA-Z_-]*:" \
		$(MAKEFILES_DIR)/std_rules.mk \
		$(MAKEFILES_DIR)/$(component)_rules.mk \
		| sed -e 's/:.*$$//' -e 's/^./    $(component)-&/'

## For debugging this makefile
mkdebug:: $(addsuffix _mkdebug, $(component))

# The actual rule for a particular component.  Specific components can
# *add* more variables by providing a 'mkdebug::' target
# (NOTE they should use a double-colon rule).
%_mkdebug::
	@echo "$(*)_SRC_DIR      = $($(*)_SRC_DIR)"
	@echo "$(*)_OBJ_DIR      = $($(*)_OBJ_DIR)"
	@echo "$(*)_INSTALL_DIR  = $($(*)_INSTALL_DIR)"
	@echo "$(*)_CONFIGENV    = $($(*)_CONFIGENV)"
	@echo "$(*)_CONFIGSCRIPT = $($(*)_CONFIGSCRIPT)"
	@echo "$(*)_CONFIGOPTS   = $($(*)_CONFIGOPTS)"
	@echo "$(*)_BUILDTOOL    = $($(*)_BUILDTOOL)"
	@echo "$(*)_BUILDENV     = $($(*)_BUILDENV)"
	@echo "$(*)_HOST         = $($(*)_HOST)"
	@echo " "
#	@echo "Standard variables:"
#	@echo "std_MAKE_QUIET='$(std_MAKE_QUIET)' std_MAKE_PARALLEL='$(std_MAKE_PARALLEL)'"
#	@echo "oskit: $(std_oskit_included); moab: $(std_moab_included); janosvm: $(std_janosvm_included)"

ifeq ($(strip $(BUILD_HOST)),)
hostcheck:

else
hostcheck:
	@if test x`hostname` != x"$(strip $(BUILD_HOST))"; then \
		echo "ERROR: Must run on $(strip $(BUILD_HOST)) (currently on `hostname`)!"; \
		false; \
	fi
endif

# eof
